#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://www.musepack.net/
# source           : http://files.musepack.net/source/mppenc-1.16.tar.bz2
# mpptools source  : http://users.zenwalk.org/user-accounts/gapan/musepack-tools/mpptools-r96.tar.bz2
#                    Actually thats a tarball I created from checking out an older svn with
#                    svn checkout -r 96 http://svn.musepack.net/mppenc/
#                    That's because the musepack team doesn't include mppdec and replaygain
#                    in their source packages any more for some reason.

# Package name
NAME="musepack-tools"
# Source package name
SRCNAME="mppenc"
# Package version
VERSION="1.16"
# Source code URL
SOURCE="http://files.musepack.net/source/mppenc-$VERSION.tar.bz2"
# Musepack tools source code URL
TOOLSSOURCE="http://users.zenwalk.org/user-accounts/gapan/$NAME/mpptools-r96.tar.bz2"
# Files that should be placed in /usr/doc/package-version/
DOCS="Changelog INSTALL"
# More docs for the mpptools
MOREDOCS="COPYING.GPL COPYING.LGPL doc/MANUAL.TXT"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="48.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: Musepack tools - tools for .mpc files
$NAME:
$NAME: The musepack-tools package contains several basic tools for working
$NAME: with compressed audio files in the musepack (.mpc) format:
$NAME: * mppenc (an .mpc encoder),
$NAME: * mppdec (a command line decoder for .mpc files) and
$NAME: * replaygain (a replaygain calculator for .mpc files)
$NAME:
$NAME:
$NAME:
$NAME:
END

# Check to see if source is present. If it's not, download it
rm -rf $SRCNAME-$VERSION
if [ -f $SRCNAME-$VERSION.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

rm -rf mpptools-r96
if [ -f mpptools-r96.tar.bz2 ]; then
	echo "Musepack tools source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $TOOLSSOURCE
fi

# Unpack source
tar xvjf $SRCNAME-$VERSION.tar.bz2
tar xvjf mpptools-r96.tar.bz2

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
#numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
numjobs='-j2'

# make and install mppenc
cd $SRCNAME-$VERSION
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
cmake .
make $numjobs
mkdir -p $PKG/usr/bin
cp -a src/mppenc $PKG/usr/bin

# make and install mpptools
cd $CWD/mpptools-r96
sed -i -e 's/-Os//' Makefile
sed -i -e 's/-march=i586//' Makefile
sed -i -e 's/-m\$(TUNE)=i686//' Makefile
make mppdec
make replaygain
cp -a mppdec replaygain $PKG/usr/bin

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$SRCNAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION
cd $CWD/mpptools-r96
cp -a $MOREDOCS $PKG/usr/doc/$NAME-$VERSION

# Compress the man page(s)
find $PKG/usr/man -type f -exec gzip -9 {} \;

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$SRCNAME-$VERSION
rm -rf mpptools-r96
rm -rf $PKG
